@@ -312,12 +312,26 @@ class LangfuseDecorator:
                                     transform_to_string,
                                 )
 
+                            # handle starlette.StreamingResponse
+                            if type(result).__name__ == "StreamingResponse" and hasattr(
+                                result, "body_iterator"
+                            ):
+                                is_return_type_generator = True
+
+                                result.body_iterator = (
+                                    self._wrap_async_generator_result(
+                                        langfuse_span_or_generation,
+                                        result.body_iterator,
+                                        transform_to_string,
+                                    )
+                                )
+
                             langfuse_span_or_generation.update(output=result)
 
                         return result
                     except Exception as e:
                         langfuse_span_or_generation.update(
-                            level="ERROR", status_message=str(e)
+                            level="ERROR", status_message=str(e) or type(e).__name__
                         )
 
                         raise e
@@ -416,12 +430,26 @@ class LangfuseDecorator:
                                     transform_to_string,
                                 )
 
+                            # handle starlette.StreamingResponse
+                            if type(result).__name__ == "StreamingResponse" and hasattr(
+                                result, "body_iterator"
+                            ):
+                                is_return_type_generator = True
+
+                                result.body_iterator = (
+                                    self._wrap_async_generator_result(
+                                        langfuse_span_or_generation,
+                                        result.body_iterator,
+                                        transform_to_string,
+                                    )
+                                )
+
                             langfuse_span_or_generation.update(output=result)
 
                         return result
                     except Exception as e:
                         langfuse_span_or_generation.update(
-                            level="ERROR", status_message=str(e)
+                            level="ERROR", status_message=str(e) or type(e).__name__
                         )
 
                         raise e
@@ -561,7 +589,7 @@ class _ContextPreservedSyncGeneratorWrapper:
             raise  # Re-raise StopIteration
 
         except Exception as e:
-            self.span.update(level="ERROR", status_message=str(e)).end()
+            self.span.update(level="ERROR", status_message=str(e) or type(e).__name__).end()
 
             raise
 
@@ -626,6 +654,6 @@ class _ContextPreservedAsyncGeneratorWrapper:
 
             raise  # Re-raise StopAsyncIteration
         except Exception as e:
-            self.span.update(level="ERROR", status_message=str(e)).end()
+            self.span.update(level="ERROR", status_message=str(e) or type(e).__name__).end()
 
             raise
