@@ -13,9 +13,9 @@ All span classes provide methods for media processing, attribute management,
 and scoring integration specific to Langfuse's observability platform.
 """
 
+import warnings
 from datetime import datetime
 from time import time_ns
-import warnings
 from typing import (
     TYPE_CHECKING,
     Any,
@@ -30,8 +30,8 @@ from typing import (
 )
 
 from opentelemetry import trace as otel_trace_api
-from opentelemetry.util._decorator import _AgnosticContextManager
 from opentelemetry.trace.status import Status, StatusCode
+from opentelemetry.util._decorator import _AgnosticContextManager
 
 from langfuse.model import PromptClient
 
@@ -45,10 +45,10 @@ from langfuse._client.attributes import (
     create_trace_attributes,
 )
 from langfuse._client.constants import (
-    ObservationTypeLiteral,
     ObservationTypeGenerationLike,
-    ObservationTypeSpanLike,
+    ObservationTypeLiteral,
     ObservationTypeLiteralNoEvent,
+    ObservationTypeSpanLike,
     get_observation_types_list,
 )
 from langfuse.logger import langfuse_logger
@@ -190,7 +190,9 @@ class LangfuseObservationWrapper:
                 {k: v for k, v in attributes.items() if v is not None}
             )
             # Set OTEL span status if level is ERROR
-            self._set_otel_span_status_if_error(level=level, status_message=status_message)
+            self._set_otel_span_status_if_error(
+                level=level, status_message=status_message
+            )
 
     def end(self, *, end_time: Optional[int] = None) -> "LangfuseObservationWrapper":
         """End the span, marking it as completed.
@@ -221,10 +223,6 @@ class LangfuseObservationWrapper:
     ) -> "LangfuseObservationWrapper":
         """Update the trace that this span belongs to.
 
-        This method updates trace-level attributes of the trace that this span
-        belongs to. This is useful for adding or modifying trace-wide information
-        like user ID, session ID, or tags.
-
         Args:
             name: Updated name for the trace
             user_id: ID of the user who initiated the trace
@@ -235,6 +233,9 @@ class LangfuseObservationWrapper:
             metadata: Additional metadata to associate with the trace
             tags: List of tags to categorize the trace
             public: Whether the trace should be publicly accessible
+
+        See Also:
+            :func:`langfuse.propagate_attributes`: Recommended replacement
         """
         if not self._otel_span.is_recording():
             return self
@@ -544,7 +545,7 @@ class LangfuseObservationWrapper:
         return data
 
     def _set_otel_span_status_if_error(
-            self, *, level: Optional[SpanLevel] = None, status_message: Optional[str] = None
+        self, *, level: Optional[SpanLevel] = None, status_message: Optional[str] = None
     ) -> None:
         """Set OpenTelemetry span status to ERROR if level is ERROR.
 
