@@ -1,5 +1,17 @@
-import typing
 from contextvars import Token
+from typing import (
+    Any,
+    Dict,
+    List,
+    Literal,
+    Optional,
+    Sequence,
+    Set,
+    Type,
+    Union,
+    cast,
+)
+from uuid import UUID
 
 import pydantic
 from opentelemetry import context, trace
@@ -16,41 +28,52 @@ from langfuse._client.span import (
     LangfuseSpan,
     LangfuseTool,
 )
+from langfuse._utils import _get_timestamp
+from langfuse.langchain.utils import _extract_model_name
 from langfuse.logger import langfuse_logger
 
 try:
-    import langchain  # noqa
+    import langchain
 
-except ImportError as e:
-    langfuse_logger.error(
-        f"Could not import langchain. The langchain integration will not work. {e}"
-    )
+    if langchain.__version__.startswith("1"):
+        # Langchain v1
+        from langchain_core.agents import AgentAction, AgentFinish
+        from langchain_core.callbacks import (
+            BaseCallbackHandler as LangchainBaseCallbackHandler,
+        )
+        from langchain_core.documents import Document
+        from langchain_core.messages import (
+            AIMessage,
+            BaseMessage,
+            ChatMessage,
+            FunctionMessage,
+            HumanMessage,
+            SystemMessage,
+            ToolMessage,
+        )
+        from langchain_core.outputs import ChatGeneration, LLMResult
 
-from typing import Any, Dict, List, Literal, Optional, Sequence, Set, Type, Union, cast
-from uuid import UUID
+    else:
+        # Langchain v0
+        from langchain.callbacks.base import (  # type: ignore
+            BaseCallbackHandler as LangchainBaseCallbackHandler,
+        )
+        from langchain.schema.agent import AgentAction, AgentFinish  # type: ignore
+        from langchain.schema.document import Document  # type: ignore
+        from langchain_core.messages import (
+            AIMessage,
+            BaseMessage,
+            ChatMessage,
+            FunctionMessage,
+            HumanMessage,
+            SystemMessage,
+            ToolMessage,
+        )
+        from langchain_core.outputs import (
+            ChatGeneration,
+            LLMResult,
+        )
 
-from langfuse._utils import _get_timestamp
-from langfuse.langchain.utils import _extract_model_name
-
-try:
-    from langchain.callbacks.base import (
-        BaseCallbackHandler as LangchainBaseCallbackHandler,
-    )
-    from langchain.schema.agent import AgentAction, AgentFinish
-    from langchain.schema.document import Document
-    from langchain_core.messages import (
-        AIMessage,
-        BaseMessage,
-        ChatMessage,
-        FunctionMessage,
-        HumanMessage,
-        SystemMessage,
-        ToolMessage,
-    )
-    from langchain_core.outputs import (
-        ChatGeneration,
-        LLMResult,
-    )
 except ImportError:
     raise ModuleNotFoundError(
         "Please install langchain to use the Langfuse langchain integration: 'pip install langchain'"
@@ -1011,7 +1034,7 @@ def _flatten_comprehension(matrix: Any) -> Any:
     return [item for row in matrix for item in row]
 
 
-def _parse_usage_model(usage: typing.Union[pydantic.BaseModel, dict]) -> Any:
+def _parse_usage_model(usage: Union[pydantic.BaseModel, dict]) -> Any:
     # maintains a list of key translations. For each key, the usage model is checked
     # and a new object will be created with the new key if the key exists in the usage model
     # All non matched keys will remain on the object.
